/**
 * 实体权限服务注册中心
 *
 * @export
 * @class AuthServiceRegister
 */
export class AuthServiceRegister {

    /**
     * 所有实体权限服务Map
     *
     * @protected
     * @type {*}
     * @memberof AuthServiceRegister
     */
    protected allAuthService: Map<string, () => Promise<any>> = new Map();

    /**
     * 已加载实体权限服务Map缓存
     *
     * @protected
     * @type {Map<string, any>}
     * @memberof AuthServiceRegister
     */
    protected serviceCache: Map<string, any> = new Map();

    /**
     * Creates an instance of AuthServiceRegister.
     * @memberof AuthServiceRegister
     */
    constructor() {
        this.init();
    }

    /**
     * 初始化
     *
     * @protected
     * @memberof AuthServiceRegister
     */
    protected init(): void {
                this.allAuthService.set('ibz5sample0005', () => import('@/authservice/ibz5-sample0005/ibz5-sample0005-auth-service'));
        this.allAuthService.set('ibz5custom', () => import('@/authservice/ibz5-custom/ibz5-custom-auth-service'));
        this.allAuthService.set('ibz5sample', () => import('@/authservice/ibz5-sample/ibz5-sample-auth-service'));
        this.allAuthService.set('ibz5supplier', () => import('@/authservice/ibz5-supplier/ibz5-supplier-auth-service'));
        this.allAuthService.set('ibz5sample0018', () => import('@/authservice/ibz5-sample0018/ibz5-sample0018-auth-service'));
        this.allAuthService.set('ibz5sample0013', () => import('@/authservice/ibz5-sample0013/ibz5-sample0013-auth-service'));
        this.allAuthService.set('ibz5sample0001', () => import('@/authservice/ibz5-sample0001/ibz5-sample0001-auth-service'));
        this.allAuthService.set('ibz5storage', () => import('@/authservice/ibz5-storage/ibz5-storage-auth-service'));
        this.allAuthService.set('ibz5orderdetail', () => import('@/authservice/ibz5-order-detail/ibz5-order-detail-auth-service'));
        this.allAuthService.set('ibz5hardware', () => import('@/authservice/ibz5-hardware/ibz5-hardware-auth-service'));
        this.allAuthService.set('ibz5sample0010', () => import('@/authservice/ibz5-sample0010/ibz5-sample0010-auth-service'));
        this.allAuthService.set('ibz5sample0006', () => import('@/authservice/ibz5-sample0006/ibz5-sample0006-auth-service'));
        this.allAuthService.set('ibz5sample0020', () => import('@/authservice/ibz5-sample0020/ibz5-sample0020-auth-service'));
        this.allAuthService.set('ibz5sample0003', () => import('@/authservice/ibz5-sample0003/ibz5-sample0003-auth-service'));
        this.allAuthService.set('ibz5sample0007', () => import('@/authservice/ibz5-sample0007/ibz5-sample0007-auth-service'));
        this.allAuthService.set('ibz5softwaresuit', () => import('@/authservice/ibz5-software-suit/ibz5-software-suit-auth-service'));
        this.allAuthService.set('ibz5sample0016', () => import('@/authservice/ibz5-sample0016/ibz5-sample0016-auth-service'));
        this.allAuthService.set('ibz5customer_intf', () => import('@/authservice/ibz5-customer-intf/ibz5-customer-intf-auth-service'));
        this.allAuthService.set('ibz5sample0002', () => import('@/authservice/ibz5-sample0002/ibz5-sample0002-auth-service'));
        this.allAuthService.set('ibz5sample0008', () => import('@/authservice/ibz5-sample0008/ibz5-sample0008-auth-service'));
        this.allAuthService.set('ibz5account', () => import('@/authservice/ibz5-account/ibz5-account-auth-service'));
        this.allAuthService.set('ibz5sample0014', () => import('@/authservice/ibz5-sample0014/ibz5-sample0014-auth-service'));
        this.allAuthService.set('ibz5ordertype', () => import('@/authservice/ibz5-order-type/ibz5-order-type-auth-service'));
        this.allAuthService.set('ibz5uniproduct', () => import('@/authservice/ibz5-uniproduct/ibz5-uniproduct-auth-service'));
        this.allAuthService.set('ibz5sample0019', () => import('@/authservice/ibz5-sample0019/ibz5-sample0019-auth-service'));
        this.allAuthService.set('ibz5sample0015', () => import('@/authservice/ibz5-sample0015/ibz5-sample0015-auth-service'));
        this.allAuthService.set('ibz5sample0004', () => import('@/authservice/ibz5-sample0004/ibz5-sample0004-auth-service'));
        this.allAuthService.set('ibz5sample0011', () => import('@/authservice/ibz5-sample0011/ibz5-sample0011-auth-service'));
        this.allAuthService.set('ibz5customermg', () => import('@/authservice/ibz5-customer-mg/ibz5-customer-mg-auth-service'));
        this.allAuthService.set('ibz5customer', () => import('@/authservice/ibz5-customer/ibz5-customer-auth-service'));
        this.allAuthService.set('ibz5sample0017', () => import('@/authservice/ibz5-sample0017/ibz5-sample0017-auth-service'));
        this.allAuthService.set('ibz5cpu', () => import('@/authservice/ibz5-cpu/ibz5-cpu-auth-service'));
        this.allAuthService.set('ibz5sample0009', () => import('@/authservice/ibz5-sample0009/ibz5-sample0009-auth-service'));
        this.allAuthService.set('ibz5sample0012', () => import('@/authservice/ibz5-sample0012/ibz5-sample0012-auth-service'));
        this.allAuthService.set('ibz5order', () => import('@/authservice/ibz5-order/ibz5-order-auth-service'));
    }

    /**
     * 加载实体权限服务
     *
     * @protected
     * @param {string} serviceName
     * @returns {Promise<any>}
     * @memberof AuthServiceRegister
     */
    protected async loadService(serviceName: string): Promise<any> {
        const service = this.allAuthService.get(serviceName);
        if (service) {
            return service();
        }
    }

    /**
     * 获取应用实体权限服务
     *
     * @param {string} name
     * @returns {Promise<any>}
     * @memberof AuthServiceRegister
     */
    public async getService(name: string): Promise<any> {
        if (this.serviceCache.has(name)) {
            return this.serviceCache.get(name);
        }
        const authService: any = await this.loadService(name);
        if (authService && authService.default) {
            const instance: any = new authService.default();
            this.serviceCache.set(name, instance);
            return instance;
        }
    }

}
export const authServiceRegister: AuthServiceRegister = new AuthServiceRegister();